/*
Author:       Pascal Peter
Copyright:    (C) 2019 Pascal Peter
License:      GNU General Public License version 3
Website:      http://pascal.peter.free.fr
Email:        pascal.peter at free.fr
*/




        
let dndHandler = {
    draggedElement: null, // Propriété pointant vers l'élément en cours de déplacement

    applyDragEvents: function(element) {
        element.draggable = true;
        let dndHandler = this; // Cette variable est nécessaire pour que l'événement "dragstart" ci-dessous accède facilement au namespace "dndHandler"
        element.addEventListener(
            'dragstart', 
            function(e) {
                dndHandler.draggedElement = e.target; // On sauvegarde l'élément en cours de déplacement
                e.dataTransfer.setData('text/plain', ''); // Nécessaire pour Firefox
                }, 
            false);
        },

    applyDropEvents: function(dropper) {
        dropper.addEventListener(
            'dragover', 
            function(e) {
                e.preventDefault(); // On autorise le drop d'éléments
                this.className = 'dropper drop_hover'; // Et on applique le design adéquat à notre zone de drop quand un élément la survole
                }, 
            false);

        dropper.addEventListener(
            'dragleave', 
            function() {
                this.className = 'dropper'; // On revient au design de base lorsque l'élément quitte la zone de drop
                });

        let dndHandler = this; // Cette variable est nécessaire pour que l'événement "drop" ci-dessous accède facilement au namespace "dndHandler"

        dropper.addEventListener(
            'drop', 
            function(e) {
                let target = e.target,
                draggedElement = dndHandler.draggedElement, // Récupération de l'élément concerné
                clonedElement = draggedElement.cloneNode(true); // On créé immédiatement le clone de cet élément
                while(target.className.indexOf('dropper') == -1) { // Cette boucle permet de remonter jusqu'à la zone de drop parente
                    target = target.parentNode;
                    }
                target.className = 'dropper'; // Application du design par défaut
                clonedElement = target.appendChild(clonedElement); // Ajout de l'élément cloné à la zone de drop actuelle
                dndHandler.applyDragEvents(clonedElement); // Nouvelle application des événements qui ont été perdus lors du cloneNode()
                draggedElement.parentNode.removeChild(draggedElement); // Suppression de l'élément d'origine
                });
        }

    };
        



function reset() {
    let nombre, divs = '';
    /*
    for (let i = 0 ; i < 3 ; i++) {
        nombre = Math.floor((Math.random() * 10) + 1) - 1;
        divs += '<div class="draggable">' + nombre + '</div>';
        nombre = Math.floor((Math.random() * 9) + 1) - 10;
        divs += '<div class="draggable">' + nombre + '</div>';
        }
    */
    nombre = Math.floor((Math.random() * 5) + 5);
    divs += '<div class="draggable">' + nombre + '</div>';
    nombre = Math.floor((Math.random() * 9) + 1) - 10;
    divs += '<div class="draggable">' + nombre + '</div>';
    nombre = Math.floor((Math.random() * 3) + 1);
    divs += '<div class="draggable">' + nombre + '</div>';
    document.getElementById('somme').innerHTML = divs;

    // Application des paramètres nécessaires aux élément déplaçables :
    let elements = document.querySelectorAll('.draggable');
    for(let i = 0 ; i < elements.length ; i++)
        dndHandler.applyDragEvents(elements[i]);

    // Application des événements nécessaires aux zones de drop :
    let droppers = document.querySelectorAll('.dropper');
    for(let i = 0 ; i < droppers.length ; i++)
        dndHandler.applyDropEvents(droppers[i]);

    }


window.onload=reset();

